# Introduction

Template for Python HTTP server project.

# Get started

- Click the **Run** button to run the project.
  ![Run](https://lf-cdn.marscode.com/obj/eden-sg/ljhwz_lkpkbvsj/ljhwZthlaukjlkulzlp/project_template/prod/04edcf103c3ed19965da6966212709d6078e241f/images/native_python/run.png)

- Go to **Ports** and preview the page at **port:8080**.
  ![CloudPort](https://lf-cdn.marscode.com/obj/eden-sg/ljhwz_lkpkbvsj/ljhwZthlaukjlkulzlp/project_template/prod/04edcf103c3ed19965da6966212709d6078e241f/images/native_python/cloud_port.png)

- Go to **Preview** and watch it.
  ![Preview](https://lf-cdn.marscode.com/obj/eden-sg/ljhwz_lkpkbvsj/ljhwZthlaukjlkulzlp/project_template/prod/04edcf103c3ed19965da6966212709d6078e241f/images/native_python/preview.png)

By default, MarsCode provide you with a default running configuration, running main.py. You can modify it in the **.vscode/launch.json**. Refer to [Visual Studio Code's doc](https://code.visualstudio.com/docs/editor/debugging) for how to configure launch.json.

# Learn more

- [Python](https://www.python.org/) - the official home of the Python programming language.

# Help

If you need help, you might be able to find an answer in our [docs](https://docs.marscode.com/). Feel free to report bugs and give us feedback [here](https://discord.gg/qtVMXEDbRw).
